var Game = {
    player: null,
    pickups: null
};

Game.preload = function() {
    this.loadImages();
    this.loadSpritesheets();
};

Game.loadImages = function() {
    game.load.image('stalin', 'assets/stalin.png');
    game.load.image('franzisco', 'assets/franzisco.png');
};

Game.loadSpritesheets = function() {
    game.load.spritesheet('boris', 'assets/boris.png', 32, 48);
}

Game.create = function() {
    this.createPhysics();
    this.createPlayer();
    this.createWorld();
    this.applyPhysicsToPlayer();
    this.createPickups();
}

Game.createPhysics = function() {
    game.physics.startSystem(game.physics.ARCADE);
    this.stage.disableVisibilityChange = true;
};

Game.createPlayer = function() {
    this.player = game.add.sprite(game.world.width / 2, 10, 'boris');
    game.camera.follow(this.player);
};

Game.createWorld = function() {
    game.world.resize(game.world.width, 10000);
    this.stage.backgroundColor = 0x0000F0;
};

Game.applyPhysicsToPlayer = function() {
    game.physics.arcade.enable(this.player);
    this.player.body.gravity.y = 100;
    this.player.body.collideWorldBounds = true;
};

Game.createPickups = function() {
    this.pickups = game.add.group();
    this.pickups.enableBody = true;

    var numPickups = game.world.height / (game.camera.height / 2);
    console.log(numPickups-1 + ' pickups will be created');
    for (var i = 1; i < numPickups; i++) {
        this.createPickup(i);
    }
}

Game.createPickup = function(i) {
    var xCoordinate = Math.random() * (game.world.width - 40);
    var yCoordinate = i * game.camera.height / 2;
    var isStalin = Math.round(Math.random());
    var spriteName = 'franzisco';
    if(isStalin) {
        spriteName = 'stalin';
    }
    var pickup = this.pickups.create(xCoordinate, yCoordinate, spriteName);
    pickup.body.immovable = true;
    pickup.body.isStalin = isStalin;
    console.log('X: ' + xCoordinate + ';Y: ' + yCoordinate + ';isStalin: ' + (isStalin == true));
}

Game.update = function() {
    game.physics.arcade.overlap(this.player, this.pickups, this.pickupItem, null, this);
    this.updateXLocation();
}

Game.updateXLocation = function() {
    var velocity = 0;
    if (game.input.mousePointer.isDown) {
        var xPos = this.player.body.position.x;
        var xInp = game.input.x;
        velocity = (xInp - xPos) * 10;
    } 
    this.player.body.velocity.x = velocity;
}

Game.pickupItem = function(player, pickup) {
    var factor = pickup.body.isStalin ? 30 : -30;
    this.player.body.gravity.y += factor;
    this.player.body.gravity.y = Math.max(this.player.body.gravity.y, 10);
    console.log(pickup.body.isStalin == true);
    pickup.kill();
}